#include <OneWire.h>
#include <DallasTemperature.h>
#include <SoftwareSerial.h>
#include <Sim800L.h>
#include <LiquidCrystal.h>

#define ONE_WIRE_BUS 12

OneWire oneWire(ONE_WIRE_BUS);
DallasTemperature sensors(&oneWire);
DeviceAddress insideThermometer;
LiquidCrystal lcd(9, 8, 5, 4, 3, 2);

Sim800L gsm(11, 10);
bool sendFree = false;
bool sendMsg = false;
String textSms, numberSms;

void setup() {
  Serial.begin(9600);

  gsm.begin();
  gsm.delAllSms();

  sensors.begin();
  sensors.getAddress(insideThermometer, 0);
  sensors.setResolution(insideThermometer, 9);

  lcd.begin(16, 2);
  lcd.print("Temp ");
}

void loop() {
  sensors.requestTemperatures();
  float tempC = sensors.getTempC(insideThermometer);

  lcd.clear();
  lcd.print("Temp ");
  lcd.print(tempC);

  gsm.getStatus();
  int idx = gsm.getIdxSms();
  
  if (idx > -1)
    receiveMessage(idx);

  if ((tempC < 5 && sendMsg) || sendFree)
  {
    char t[5];
    dtostrf(tempC, 3, 2, t);
    gsm.sendSms("+48xxxxxxxxx", t); //tutaj należy podać nr telefonu na który mają trafiać sms'y

    if (sendFree == false)
      sendMsg = false;

    sendFree = false;
  } else if (tempC > 6) // próg aktywacji wysyłania sms po już wysłanym sms.
  {
    sendMsg = true;
  }

  delay(5000);
}

void receiveMessage(int idx) {
  numberSms = gsm.getNumberSms(idx); 

  textSms = gsm.readSms(idx);
  textSms.toUpperCase();

  if (textSms.indexOf("TEMP") != -1) {
    sendFree = true;
    gsm.delAllSms();
    gsm.setIdxSms();
  }
}
